@@ -17,8 +17,6 @@
 #include "configtreetext.h"
 #include "custom.h"
 
-#include <iostream>
-#include <iomanip>
 #include <QDropEvent>
 #include <QFileDialog>
 #include <QMessageBox>
@@ -48,7 +46,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "24.01.1"
+#define VERSION "24.06"
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -187,32 +185,36 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 #endif
 
     //tests
-    ui->actionQuit->setIcon(QIcon::fromTheme("application-exit"));
-    ui->actionClose_All->setIcon(QIcon::fromTheme("dialog-close"));
-    ui->actionOpen->setIcon(QIcon::fromTheme("document-open"));
-    ui->actionOpen_Folder->setIcon(QIcon::fromTheme("document-open-folder"));
-    ui->actionAbout->setIcon(QIcon::fromTheme("help-about"));
-    ui->actionExport->setIcon(QIcon::fromTheme("document-export"));
-    ui->actionPreferences->setIcon(QIcon::fromTheme("configure"));
+#if QT_VERSION > QT_VERSION_CHECK(6, 7, 0)
+    ui->actionQuit->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::WindowClose));
+    ui->actionClose_All->setIcon(QIcon::fromTheme(QIcon::ThemeIcon::WindowClose));
+#else
+    ui->actionQuit->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
+    ui->actionClose_All->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
+#endif
+    ui->actionOpen->setIcon(QIcon(":/icon/openfile.svg"));
+    ui->actionOpen_Folder->setIcon(QIcon(":/icon/opendir.svg"));
+    ui->actionAbout->setIcon(QIcon(":/icon/about.svg"));
+    ui->actionExport->setIcon(QIcon(":/icon/export.svg"));
 
     menuView = new QMenu();
-   QActionGroup* menuItemGroup = new QActionGroup(this);
-   for(int v=VIEW_EASY;v<NB_VIEW;v++) {
-       QAction* action = new QAction(nameView((ViewMode)v), menuItemGroup);
-       action->setCheckable(true);
-       if(view==v)
-           action->setChecked(true);
-       action->setProperty("view",v);
-       ui->menuView->addAction(action);
-       menuView->addAction(action);
-   }
-   connect(menuItemGroup,SIGNAL(triggered(QAction*)),this,SLOT(actionView_toggled(QAction*)));
+    QActionGroup* menuItemGroup = new QActionGroup(this);
+    for(int v=VIEW_EASY;v<NB_VIEW;v++) {
+        QAction* action = new QAction(nameView((ViewMode)v), menuItemGroup);
+        action->setCheckable(true);
+        if(view==v)
+            action->setChecked(true);
+        action->setProperty("view",v);
+        ui->menuView->addAction(action);
+        menuView->addAction(action);
+    }
+    connect(menuItemGroup,SIGNAL(triggered(QAction*)),this,SLOT(actionView_toggled(QAction*)));
 
-   buttonView = new QToolButton();
-   buttonView->setText("view");
-   buttonView->setIcon(QIcon::fromTheme("view-list-details"));
-   connect(buttonView, SIGNAL(clicked()), this, SLOT(buttonViewClicked()));
-   ui->toolBar->addWidget(buttonView);
+    buttonView = new QToolButton();
+    buttonView->setText("view");
+    buttonView->setIcon(QIcon(":/icon/view.svg"));
+    connect(buttonView, SIGNAL(clicked()), this, SLOT(buttonViewClicked()));
+    ui->toolBar->addWidget(buttonView);
 
     ui->toolBar->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui->toolBar,SIGNAL(customContextMenuRequested(QPoint)),this,SLOT(toolBarOptions(QPoint)));
@@ -271,33 +273,33 @@ void MainWindow::checkForNewVersion() {
     reply = qnam.get(QNetworkRequest(url));
     qDebug() << "downloading " << url.toString();
 
-     connect(reply, SIGNAL(finished()), this, SLOT(httpFinished()));
-     connect(reply, SIGNAL(readyRead()), this, SLOT(httpReadyRead()));
+    connect(reply, SIGNAL(finished()), this, SLOT(httpFinished()));
+    connect(reply, SIGNAL(readyRead()), this, SLOT(httpReadyRead()));
 
 }
 
 void MainWindow::httpFinished()
 {
-         if (reply->error()) {
-             qDebug() << "Download failed";
-         } else {
-             qDebug() << "Downloaded file to temp string.";
-         }
+    if (reply->error()) {
+        qDebug() << "Download failed";
+    } else {
+        qDebug() << "Downloaded file to temp string.";
+    }
 
-         ZtringListList X;
-         X.Write(file.toStdString().c_str());
-         if (isNewer(wstring2QString(X("NewVersion")),QString(VERSION))) {
-             qDebug() << "New version is available.";
-             qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
-             ui->menuBar->addAction(Tr("Update to new version"),this,SLOT(updateToNewVersion()));
-         } else {
-             qDebug() << "No new version available.";
-             qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
-         }
+    ZtringListList X;
+    X.Write(file.toStdString().c_str());
+    if (isNewer(wstring2QString(X("NewVersion")),QString(VERSION))) {
+        qDebug() << "New version is available.";
+        qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
+        ui->menuBar->addAction(Tr("Update to new version"),this,SLOT(updateToNewVersion()));
+    } else {
+        qDebug() << "No new version available.";
+        qDebug() << "latest is " << wstring2QString(X("NewVersion")).toStdString().c_str();
+    }
 
-         reply->deleteLater();
-         reply = 0;
-         file = "";
+    reply->deleteLater();
+    reply = 0;
+    file = "";
 }
 
 void MainWindow::updateToNewVersion() {
@@ -306,7 +308,7 @@ void MainWindow::updateToNewVersion() {
 
 void MainWindow::httpReadyRead()
 {
-        file.append(reply->readAll());
+    file.append(reply->readAll());
 }
 #endif //NEW_VERSION
 
@@ -486,7 +488,8 @@ void MainWindow::openDir(QString dirName) {
 }
 
 void MainWindow::refreshDisplay() {
-    QFont font("Mono");
+    QStringList fonts = { "Cascadia Mono", "Mono" };
+    QFont font(fonts);
     font.setStyleHint(QFont::TypeWriter);
 
     ui->actionAdapt_columns_to_content->setVisible(false);
@@ -777,7 +780,7 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
                             B=B.mid(level);
 
                         if (level==tree.count() && tree.back()->childCount())
-                           tree.append(tree.back()->child(tree.back()->childCount()-1));
+                            tree.append(tree.back()->child(tree.back()->childCount()-1));
                         else if (level<tree.count()-1)
                             tree.resize(level+1);
 
@@ -1009,7 +1012,7 @@ void MainWindow::on_actionOpen_Folder_triggered()
 #endif
     openDir(dirName);
 
-   refreshDisplay();
+    refreshDisplay();
 }
 
 void MainWindow::on_actionAbout_triggered()
